@@ -3,8 +3,8 @@ This file contains the runner class which runs jobs (input as path to json)
 """
 import pandas as pd
 
-from src.deepframe.utils import Logger, Timer, bcolors
-from src.deepframe.Model.NeuralNetworks.FullyConnected import AutomaticNetwork
+from deepframe.utils import Logger, Timer, bcolors
+from deepframe.Model.NeuralNetworks.FullyConnected import AutomaticNetwork
 from torch.utils.data import random_split, DataLoader
 from pathlib import Path
 from torch import autograd
